@@ -35,6 +35,7 @@
 #elif	defined(_WIN32) || defined(WIN32) || defined(__WIN32__)
 #  define IUTEST_OS_WINDOWS				1
 #  define IUTEST_PLATFORM				"Windows"
+#  define WIN32_LEAN_AND_MEAN
 #  include <windows.h>
 #  if	defined(_WIN32_WCE)
 #    define IUTEST_OS_WINDOWS_MOBILE	1
@@ -78,6 +79,14 @@
 #endif
 
 // c++11
+#if (defined(__cplusplus) && __cplusplus >= 201103L) || defined(__GXX_EXPERIMENTAL_CXX0X__)
+#  define IUTEST_HAS_CXX11		1
+#endif
+
+#ifndef IUTEST_HAS_CXX11
+#  define IUTEST_HAS_CXX11		0
+#endif
+
 // nullptr
 #if !defined(IUTEST_HAS_NULLPTR)
 #  if	defined(__clang__)
@@ -145,12 +154,12 @@
 #endif
 
 #if IUTEST_HAS_CONSTEXPR
-#  define IUTEST_CONSTEXPR			constexpr
-#  define IUTEST_CONSTEXPR_OR_CONST	constexpr
+#  define IUTEST_CXX_CONSTEXPR			constexpr
+#  define IUTEST_CXX_CONSTEXPR_OR_CONST	constexpr
 #else
 #  define IUTEST_NO_CONSTEXPR
-#  define IUTEST_CONSTEXPR
-#  define IUTEST_CONSTEXPR_OR_CONST	const
+#  define IUTEST_CXX_CONSTEXPR
+#  define IUTEST_CXX_CONSTEXPR_OR_CONST	const
 #endif
 
 // rvalue reference
@@ -190,9 +199,54 @@
 #endif
 
 #if IUTEST_HAS_DELETED_FUNCTIONS
-#  define IUTEST_DECL_DELETED_FUNCTION	= delete
+#  define IUTEST_CXX_DELETED_FUNCTION	= delete
 #else
-#  define IUTEST_DECL_DELETED_FUNCTION
+#  define IUTEST_CXX_DELETED_FUNCTION
+#endif
+
+// default function
+#ifndef IUTEST_HAS_DEFAULT_FUNCTIONS
+#  if	defined(__clang__)
+#    if __has_feature(cxx_defaulted_functions)
+#      define IUTEST_HAS_DEFAULT_FUNCTIONS	1
+#    endif
+#  elif defined(__GNUC__)
+#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 4)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#      define IUTEST_HAS_DEFAULT_FUNCTIONS	1
+#    endif
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_DEFAULT_FUNCTIONS
+#  define IUTEST_HAS_DEFAULT_FUNCTIONS		0
+#endif
+
+#if IUTEST_HAS_DEFAULT_FUNCTIONS
+#  define IUTEST_CXX_DEFAULT_FUNCTION	= default;
+#else
+#  define IUTEST_CXX_DEFAULT_FUNCTION	{}
+#endif
+
+// initializer_list
+#ifndef IUTEST_HAS_INITIALIZER_LIST
+#  if	defined(__clang__)
+#    if __has_feature(cxx_generalized_initializers)
+#      define IUTEST_HAS_INITIALIZER_LIST	1
+#    endif
+#  elif defined(__GNUC__)
+#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 4)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#      define IUTEST_HAS_INITIALIZER_LIST	1
+#    endif
+#  elif	defined(_MSC_VER)
+#    if _MSC_FULL_VER == 170051025
+#      define IUTEST_HAS_INITIALIZER_LIST	1
+#      include <initializer_list>
+#    endif
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_INITIALIZER_LIST
+#  define IUTEST_HAS_INITIALIZER_LIST		0
 #endif
 
 // variadic template
@@ -225,7 +279,7 @@
 #      define IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES	1
 #    endif
 #  elif	defined(__GNUC__)
-#    if defined(__VARIADIC_TEMPLATES) || (__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7) && (__GNUC_PATCHLEVEL__ >= 1) && defined(__GXX_EXPERIMENTAL_CXX0X__))
+#    if defined(__VARIADIC_TEMPLATES) || (__GNUC__ > 4) || ((__GNUC__ == 4) && (__GNUC_MINOR__ > 7)) || ((__GNUC__ == 4) && (__GNUC_MINOR__ >= 7) && (__GNUC_PATCHLEVEL__ >= 1) && defined(__GXX_EXPERIMENTAL_CXX0X__))
 #      define IUTEST_HAS_VARIADIC_TEMPLATE_TEMPLATES	1
 #    endif
 #  elif	defined(_MSC_VER)
@@ -344,6 +398,68 @@
 #  endif
 #endif
 
+// noexcept
+#ifndef IUTEST_HAS_NOEXCEPT
+#  if	defined(__clang__)
+#    if __has_feature(cxx_noexcept)
+#      define IUTEST_HAS_NOEXCEPT	1
+#    endif
+#  elif	defined(__GNUC__)
+#    if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6)) && defined(__GXX_EXPERIMENTAL_CXX0X__)
+#      define IUTEST_HAS_NOEXCEPT	1
+#    endif
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_NOEXCEPT
+#  define IUTEST_HAS_NOEXCEPT	0
+#endif
+
+#ifndef IUTEST_CXX_NOEXCEPT
+#  if IUTEST_HAS_NOEXCEPT
+#    define IUTEST_CXX_NOEXCEPT(expr_)		noexcept(expr_)
+#  else
+#    define IUTEST_CXX_NOEXCEPT(expr_)
+#  endif
+#endif
+
+#ifndef IUTEST_CXX_NOEXCEPT_SPEC
+#  if IUTEST_HAS_NOEXCEPT
+#    define IUTEST_CXX_NOEXCEPT_SPEC		noexcept
+#  else
+#    define IUTEST_CXX_NOEXCEPT_SPEC
+#  endif
+#endif
+
+#ifndef IUTEST_CXX_NOEXCEPT_AS
+#  if IUTEST_HAS_NOEXCEPT
+#    define IUTEST_CXX_NOEXCEPT_AS(expr_)	noexcept( noexcept(expr_) )
+#  else
+#    define IUTEST_CXX_NOEXCEPT_AS(expr_)
+#  endif
+#endif
+
+#ifndef IUTEST_CXX_NOTHROW
+#  if IUTEST_HAS_NOEXCEPT
+#    define IUTEST_CXX_NOTHROW	noexcept
+#  else
+#    define IUTEST_CXX_NOTHROW	throw()
+#  endif
+#endif
+
+// extern template
+#ifndef IUTEST_HAS_EXTERN_TEMPLATE
+#  if defined(_MSC_VER) && _MSC_VER >= 1400
+#    define IUTEST_HAS_EXTERN_TEMPLATE	1
+#  elif defined(__GNUC__) || defined(__clang__)
+#    define IUTEST_HAS_EXTERN_TEMPLATE	1
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_EXTERN_TEMPLATE
+#  define IUTEST_HAS_EXTERN_TEMPLATE	0
+#endif
+
 // c++
 // attribute
 #ifndef IUTEST_ATTRIBUTE_UNUSED_
@@ -485,19 +601,76 @@
 #endif
 
 // partial template specialization
-#ifndef IUTEST_NO_PARTIAL_TEMPLATE_SPECIALIZATION
-#  if	defined(_MSC_VER) && (_MSC_VER < 1300)
-#    define IUTEST_NO_PARTIAL_TEMPLATE_SPECIALIZATION	1
+#ifndef IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION
+#  if	defined(_MSC_VER) && (_MSC_VER < 1310)
+#    define IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION	1
+#  endif
+#endif
+
+// explicit class member template specialization
+#ifndef IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION
+#  if	defined(_MSC_VER)
+#    define IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION	1
+#  else
+#    define IUTEST_HAS_CLASS_MEMBER_TEMPLATE_SPECIALIZATION	0
+#  endif
+#endif
+
+// function template ordering
+#ifndef IUTEST_NO_FUNCTION_TEMPLATE_ORDERING
+#  if	defined(_MSC_VER) && (_MSC_VER < 1310)
+#    define IUTEST_NO_FUNCTION_TEMPLATE_ORDERING		1
 #  endif
 #endif
 
 // in class member initialization
 #ifndef IUTEST_NO_INCLASS_MEMBER_INITIALIZATION
-#  if defined(_MSC_VER) && _MSC_VER < 1300
+#  if defined(_MSC_VER) && _MSC_VER < 1310
 #    define IUTEST_NO_INCLASS_MEMBER_INITIALIZATION		1
 #  endif
 #endif
 
+// explicit function template instantiation
+#ifndef IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS
+#  if defined(_MSC_VER) && _MSC_VER < 1310
+#    define IUTEST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS	1
+#  endif
+#endif
+
+// sfinae
+#ifndef IUTEST_NO_SFINAE
+#  if defined(_MSC_VER) && _MSC_VER < 1310
+#    define IUTEST_NO_SFINAE	1
+#  endif
+#endif
+
+// template template
+#ifndef IUTEST_NO_TEMPLATE_TEMPLATES
+#  if defined(_MSC_VER) && _MSC_VER < 1310
+#    define IUTEST_NO_TEMPLATE_TEMPLATES	1
+#  endif
+#endif
+
+// void return
+#ifndef IUTEST_NO_VOID_RETURNS
+#  if defined(_MSC_VER) && _MSC_VER < 1300
+#    define IUTEST_NO_VOID_RETURNS			1
+#  endif
+#endif
+
+// ADL
+#ifndef IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP
+#  if defined(_MSC_VER) && _MSC_VER < 1310
+#    define IUTEST_NO_ARGUMENT_DEPENDENT_LOOKUP	1
+#  endif
+#endif
+
+#ifndef IUTEST_NO_PRIVATE_IN_AGGREGATE
+#  if defined(_MSC_VER) && _MSC_VER < 1310
+#    define IUTEST_NO_PRIVATE_IN_AGGREGATE	1
+#  endif
+#endif
+
 // secure lib
 #if defined(_MSC_VER) 
 #  if defined(__STDC_WANT_SECURE_LIB__) && __STDC_WANT_SECURE_LIB__
@@ -512,4 +685,8 @@
 // pragma
 #include "iutest_pragma.hpp"
 
+#if defined(_MSC_VER) && _MSC_VER < 1300
+#  pragma warning(disable:4786)	// ident trunc to '255' chars in debug info
+#endif
+
 #endif
