@@ -127,24 +127,25 @@ public:
  * @tparam T	= p[^^
 */
 template<typename T>
-class iuValueInParamsGenerator : public iuIParamGenerator<T>
+class iuValuesInParamsGenerator : public iuIParamGenerator<T>
 {
 	typedef ::std::vector<T>	params_t;
 	params_t	m_values;
 	typename params_t::const_iterator m_it;
 public:
-	iuValueInParamsGenerator(const params_t& values)
+	iuValuesInParamsGenerator(const params_t& values)
 		: m_values(values) {}
 	template<typename Container>
-	iuValueInParamsGenerator(const Container& values)
+	iuValuesInParamsGenerator(const Container& values)
 	{
 		for( typename Container::const_iterator it = values.begin(), end=values.end(); it != end; ++it )
 		{
 			m_values.push_back(static_cast<T>(*it));
 		}
 	}
+#if !defined(IUTEST_NO_TEMPLATE_PARTIAL_SPECIALIZATION)
 	template<typename TT, size_t SIZE>
-	iuValueInParamsGenerator(const TT (&values)[SIZE])
+	iuValuesInParamsGenerator(const TT (&values)[SIZE])
 	{
 		const TT* begin = values;
 		for( const TT* end = values+SIZE; begin != end; ++begin )
@@ -152,15 +153,24 @@ public:
 			m_values.push_back(static_cast<T>(*begin));
 		}
 	}
+#endif
 
 	template<typename Ite>
-	iuValueInParamsGenerator(Ite begin, Ite end)
+	iuValuesInParamsGenerator(Ite begin, Ite end)
 	{
 		for( ; begin != end; ++begin )
 		{
 			m_values.push_back(static_cast<T>(*begin));
 		}
 	}
+
+#if IUTEST_HAS_INITIALIZER_LIST
+	iuValuesInParamsGenerator(::std::initializer_list<T> l)
+	{
+		m_values.insert(m_values.end(), l.begin(), l.end());
+	}
+#endif
+
 public:
 	virtual	void	Begin(void) { m_it = m_values.begin(); }
 	virtual T		GetCurrent(void) const	{ return *m_it; }
@@ -202,7 +212,7 @@ public:
 	operator	iuIParamGenerator<T>* (void) const
 	{
 		make_array<T> ar(v);
-		return new iuValueInParamsGenerator<T>(ar.val);
+		return new iuValuesInParamsGenerator<T>(ar.val);
 	}
 private:
 	_MyTuple v;
@@ -223,83 +233,83 @@ public:
 	{
 		const T val[] = { static_cast<T>(v1), static_cast<T>(v2)
 		};
-		return new iuValueInParamsGenerator<T>(val);
+		return new iuValuesInParamsGenerator<T>(val);
 	}
 private:
 	A1	v1;	A2	v2;
 };
 */
-#define IUTEST_DECL_VALUEARRAY_CONSTRUCT_(i, p1, p2)	IUTEST_PP_CAT(p1, i)(IUTEST_PP_CAT(p2, i))
-#define IUTEST_DECL_VALUEARRAY_STATICCAST_(i, p1, p2)	static_cast<p1>(IUTEST_PP_CAT(p2, i))
-#define IUTEST_DECL_VALUEARRAY_VARIABLE_(i, p1, p2)		IUTEST_PP_CAT(p1, i) IUTEST_PP_CAT(p2, i);
-#define IUTEST_DECL_VALUEARRAY_(n)						\
+#define IIUT_DECL_VALUEARRAY_CONSTRUCT_(i, p1, p2)		IUTEST_PP_CAT(p1, i)(IUTEST_PP_CAT(p2, i))
+#define IIUT_DECL_VALUEARRAY_STATICCAST_(i, p1, p2)		static_cast<p1>(IUTEST_PP_CAT(p2, i))
+#define IIUT_DECL_VALUEARRAY_VARIABLE_(i, p1, p2)		IUTEST_PP_CAT(p1, i) IUTEST_PP_CAT(p2, i);
+#define IIUT_DECL_VALUEARRAY_(n)						\
 	template< IUTEST_PP_ENUM_PARAMS(n, typename A) >	\
 	class IUTEST_PP_CAT(iuValueArray, n) {				\
 	public:												\
 		IUTEST_PP_CAT(iuValueArray, n)( IUTEST_PP_ENUM_BINARY_PARAMS(n, A, a) )		\
-		: IUTEST_PP_ENUM_BINARY(n, IUTEST_DECL_VALUEARRAY_CONSTRUCT_, v, a) {}		\
+		: IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_VALUEARRAY_CONSTRUCT_, v, a) {}		\
 		template<typename T>operator iuIParamGenerator<T>* (void) const {			\
-			const T val[] = { IUTEST_PP_ENUM_BINARY(n, IUTEST_DECL_VALUEARRAY_STATICCAST_, T, v) };	\
-			return new iuValueInParamsGenerator<T>(val);							\
+			const T val[] = { IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_VALUEARRAY_STATICCAST_, T, v) };	\
+			return new iuValuesInParamsGenerator<T>(val);							\
 		}																			\
-	private: IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_VALUEARRAY_VARIABLE_, A, v)		\
+	private: IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_VALUEARRAY_VARIABLE_, A, v)		\
 	}
 
-IUTEST_DECL_VALUEARRAY_(1);
-IUTEST_DECL_VALUEARRAY_(2);
-IUTEST_DECL_VALUEARRAY_(3);
-IUTEST_DECL_VALUEARRAY_(4);
-IUTEST_DECL_VALUEARRAY_(5);
-IUTEST_DECL_VALUEARRAY_(6);
-IUTEST_DECL_VALUEARRAY_(7);
-IUTEST_DECL_VALUEARRAY_(8);
-IUTEST_DECL_VALUEARRAY_(9);
-IUTEST_DECL_VALUEARRAY_(10);
-IUTEST_DECL_VALUEARRAY_(11);
-IUTEST_DECL_VALUEARRAY_(12);
-IUTEST_DECL_VALUEARRAY_(13);
-IUTEST_DECL_VALUEARRAY_(14);
-IUTEST_DECL_VALUEARRAY_(15);
-IUTEST_DECL_VALUEARRAY_(16);
-IUTEST_DECL_VALUEARRAY_(17);
-IUTEST_DECL_VALUEARRAY_(18);
-IUTEST_DECL_VALUEARRAY_(19);
-IUTEST_DECL_VALUEARRAY_(20);
-IUTEST_DECL_VALUEARRAY_(21);
-IUTEST_DECL_VALUEARRAY_(22);
-IUTEST_DECL_VALUEARRAY_(23);
-IUTEST_DECL_VALUEARRAY_(24);
-IUTEST_DECL_VALUEARRAY_(25);
-IUTEST_DECL_VALUEARRAY_(26);
-IUTEST_DECL_VALUEARRAY_(27);
-IUTEST_DECL_VALUEARRAY_(28);
-IUTEST_DECL_VALUEARRAY_(29);
-IUTEST_DECL_VALUEARRAY_(30);
-IUTEST_DECL_VALUEARRAY_(31);
-IUTEST_DECL_VALUEARRAY_(32);
-IUTEST_DECL_VALUEARRAY_(33);
-IUTEST_DECL_VALUEARRAY_(34);
-IUTEST_DECL_VALUEARRAY_(35);
-IUTEST_DECL_VALUEARRAY_(36);
-IUTEST_DECL_VALUEARRAY_(37);
-IUTEST_DECL_VALUEARRAY_(38);
-IUTEST_DECL_VALUEARRAY_(39);
-IUTEST_DECL_VALUEARRAY_(40);
-IUTEST_DECL_VALUEARRAY_(41);
-IUTEST_DECL_VALUEARRAY_(42);
-IUTEST_DECL_VALUEARRAY_(43);
-IUTEST_DECL_VALUEARRAY_(44);
-IUTEST_DECL_VALUEARRAY_(45);
-IUTEST_DECL_VALUEARRAY_(46);
-IUTEST_DECL_VALUEARRAY_(47);
-IUTEST_DECL_VALUEARRAY_(48);
-IUTEST_DECL_VALUEARRAY_(49);
-IUTEST_DECL_VALUEARRAY_(50);
+IIUT_DECL_VALUEARRAY_(1);
+IIUT_DECL_VALUEARRAY_(2);
+IIUT_DECL_VALUEARRAY_(3);
+IIUT_DECL_VALUEARRAY_(4);
+IIUT_DECL_VALUEARRAY_(5);
+IIUT_DECL_VALUEARRAY_(6);
+IIUT_DECL_VALUEARRAY_(7);
+IIUT_DECL_VALUEARRAY_(8);
+IIUT_DECL_VALUEARRAY_(9);
+IIUT_DECL_VALUEARRAY_(10);
+IIUT_DECL_VALUEARRAY_(11);
+IIUT_DECL_VALUEARRAY_(12);
+IIUT_DECL_VALUEARRAY_(13);
+IIUT_DECL_VALUEARRAY_(14);
+IIUT_DECL_VALUEARRAY_(15);
+IIUT_DECL_VALUEARRAY_(16);
+IIUT_DECL_VALUEARRAY_(17);
+IIUT_DECL_VALUEARRAY_(18);
+IIUT_DECL_VALUEARRAY_(19);
+IIUT_DECL_VALUEARRAY_(20);
+IIUT_DECL_VALUEARRAY_(21);
+IIUT_DECL_VALUEARRAY_(22);
+IIUT_DECL_VALUEARRAY_(23);
+IIUT_DECL_VALUEARRAY_(24);
+IIUT_DECL_VALUEARRAY_(25);
+IIUT_DECL_VALUEARRAY_(26);
+IIUT_DECL_VALUEARRAY_(27);
+IIUT_DECL_VALUEARRAY_(28);
+IIUT_DECL_VALUEARRAY_(29);
+IIUT_DECL_VALUEARRAY_(30);
+IIUT_DECL_VALUEARRAY_(31);
+IIUT_DECL_VALUEARRAY_(32);
+IIUT_DECL_VALUEARRAY_(33);
+IIUT_DECL_VALUEARRAY_(34);
+IIUT_DECL_VALUEARRAY_(35);
+IIUT_DECL_VALUEARRAY_(36);
+IIUT_DECL_VALUEARRAY_(37);
+IIUT_DECL_VALUEARRAY_(38);
+IIUT_DECL_VALUEARRAY_(39);
+IIUT_DECL_VALUEARRAY_(40);
+IIUT_DECL_VALUEARRAY_(41);
+IIUT_DECL_VALUEARRAY_(42);
+IIUT_DECL_VALUEARRAY_(43);
+IIUT_DECL_VALUEARRAY_(44);
+IIUT_DECL_VALUEARRAY_(45);
+IIUT_DECL_VALUEARRAY_(46);
+IIUT_DECL_VALUEARRAY_(47);
+IIUT_DECL_VALUEARRAY_(48);
+IIUT_DECL_VALUEARRAY_(49);
+IIUT_DECL_VALUEARRAY_(50);
 
-#undef IUTEST_DECL_VALUEARRAY_CONSTRUCT_
-#undef IUTEST_DECL_VALUEARRAY_STATICCAST_
-#undef IUTEST_DECL_VALUEARRAY_VARIABLE_
-#undef IUTEST_DECL_VALUEARRAY_
+#undef IIUT_DECL_VALUEARRAY_CONSTRUCT_
+#undef IIUT_DECL_VALUEARRAY_STATICCAST_
+#undef IIUT_DECL_VALUEARRAY_VARIABLE_
+#undef IIUT_DECL_VALUEARRAY_
 
 #endif
 
@@ -514,23 +524,24 @@ public:
 };
 */
 
-#define IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_TYPEDEF_(i, p1, p2)		\
+#define IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_TYPEDEF_(i, p1, p2)		\
 	typedef iuParamGenerator<IUTEST_PP_CAT(p1, i)> IUTEST_PP_CAT(p2, i);
 
-#define IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_TUPLEGET_(i, param)		\
+#define IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_TUPLEGET_(i, param)		\
 	tuples::get<i>(param)
 
-#define IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_(n)				\
+#define IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_(n)					\
 	iuICartesianProductGeneratorBase< iuParamGenerator<T0>				\
-		, IUTEST_PP_CAT(iuCartesianProductGenerator, IUTEST_PP_DEC(n))< IUTEST_PP_ENUM_SHIFTED_PARAMS(IUTEST_PP_DEC(n), T) >	\
+		, IUTEST_PP_CAT(iuCartesianProductGenerator, IUTEST_PP_DEC(n))< \
+			IUTEST_PP_ENUM_SHIFTED_PARAMS(IUTEST_PP_DEC(n), T) >		\
 		, tuples::tuple< IUTEST_PP_ENUM_PARAMS(n, T) > >
 
-#define IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(n)							\
+#define IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(n)							\
 	template< IUTEST_PP_ENUM_PARAMS(n, typename T) >						\
 	class IUTEST_PP_CAT(iuCartesianProductGenerator, n)						\
-	: public IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_(n) {				\
-		typedef IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_(n) _Mybase;	\
-		IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_TYPEDEF_, T, Generator)			\
+	: public IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_(n) {				\
+		typedef IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_(n) _Mybase;		\
+		IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_TYPEDEF_, T, Generator)			\
 	public:																	\
 		typedef tuples::tuple< IUTEST_PP_ENUM_PARAMS(n, T) > ParamType;		\
 		IUTEST_PP_CAT(iuCartesianProductGenerator, n)( IUTEST_PP_ENUM_BINARY_PARAMS(n, const Generator, &g) ) \
@@ -541,22 +552,22 @@ public:
 			tuples::tuple< IUTEST_PP_ENUM_SHIFTED_PARAMS(IUTEST_PP_DEC(n), T) >	\
 			params(this->m_g2.GetCurrent());								\
 			return ParamType(this->m_g1.GetCurrent(), IUTEST_PP_ENUM(IUTEST_PP_DEC(n)	\
-				, IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_TUPLEGET_, params) );			\
+				, IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_TUPLEGET_, params) );			\
 		}																	\
 	}
 
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(3);
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(4);
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(5);
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(6);
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(7);
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(8);
-IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_(9);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(3);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(4);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(5);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(6);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(7);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(8);
+IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_(9);
 
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_TYPEDEF_
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_TUPLEGET_
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_GENERATOR_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_TYPEDEF_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_TUPLEGET_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_BASE_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_GENERATOR_
 
 // iuCartesianProductHolder
 
@@ -587,40 +598,40 @@ private:
 };
 */
 
-#define IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_CONSTRUCT_(i, p1, p2)	IUTEST_PP_CAT(p1, i)(IUTEST_PP_CAT(p2, i))
-#define IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_(i, p1, p2)	\
+#define IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_CONSTRUCT_(i, p1, p2)	IUTEST_PP_CAT(p1, i)(IUTEST_PP_CAT(p2, i))
+#define IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_(i, p1, p2)	\
 	static_cast< iuIParamGenerator< IUTEST_PP_CAT(p1, i) >* >(IUTEST_PP_CAT(p2, i))
-#define IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_(i, p1, p2)	IUTEST_PP_CAT(p1, i) IUTEST_PP_CAT(p2, i);
+#define IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_(i, p1, p2)	IUTEST_PP_CAT(p1, i) IUTEST_PP_CAT(p2, i);
 
-#define IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(n)				\
+#define IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(n)					\
 	template< IUTEST_PP_ENUM_PARAMS(n, typename Generator) >	\
 	class IUTEST_PP_CAT(iuCartesianProductHolder, n) {			\
 		typedef IUTEST_PP_CAT(iuCartesianProductHolder, n)< IUTEST_PP_ENUM_PARAMS(n, Generator) > _Myt;		\
 	public:														\
 		IUTEST_PP_CAT(iuCartesianProductHolder, n)( IUTEST_PP_ENUM_BINARY_PARAMS(n, const Generator, &g) )	\
-		: IUTEST_PP_ENUM_BINARY(n, IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_CONSTRUCT_, m_g, g) {}				\
+		: IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_CONSTRUCT_, m_g, g) {}				\
 		template< IUTEST_PP_ENUM_PARAMS(n, typename T) >		\
 		operator iuIParamGenerator< tuples::tuple< IUTEST_PP_ENUM_PARAMS(n, T) > >* (void) const {			\
 			return new IUTEST_PP_CAT(iuCartesianProductGenerator, n)< IUTEST_PP_ENUM_PARAMS(n, T) >(		\
-				IUTEST_PP_ENUM_BINARY(n, IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_, T, m_g) );		\
+				IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_, T, m_g) );			\
 		}														\
 	private: void operator = (const _Myt&) {}					\
-		IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_, const Generator, m_g)	\
+		IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_, const Generator, m_g)		\
 	}
 
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(2);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(3);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(4);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(5);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(6);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(7);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(8);
-IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_(9);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(2);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(3);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(4);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(5);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(6);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(7);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(8);
+IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_(9);
 
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_CONSTRUCT_
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_
-#undef IUTEST_DECL_CARTESIAN_PRODUCT_HOLDER_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_CONSTRUCT_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_STATICCAST_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_VARIABLE_
+#undef IIUT_DECL_CARTESIAN_PRODUCT_HOLDER_
 
 #endif
 
@@ -866,7 +877,7 @@ public:
 			params.push_back( MakeParam<0, Args...>(params_list, indexes) );
 		}
 
-		return new iuValueInParamsGenerator< ParamType >(params);
+		return new iuValuesInParamsGenerator< ParamType >(params);
 	}
 private:
 	template<int N, typename T1, typename... TArgs>
@@ -1038,56 +1049,56 @@ public:
 				) );
 		}
 
-		return new iuValueInParamsGenerator< ParamType >(params);
+		return new iuValuesInParamsGenerator< ParamType >(params);
 	}
 };
 */
 
-#define IUTEST_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_(i, p1, p2)		\
+#define IIUT_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_(i, p1, p2)			\
 	p1<IUTEST_PP_CAT(T, i)> IUTEST_PP_CAT(p2, i);
-#define IUTEST_DECL_PAIRWISE_GENERATOR_MAKEPARAM_VECTOR_(i, p1, p2)	\
+#define IIUT_DECL_PAIRWISE_GENERATOR_MAKEPARAM_VECTOR_(i, p1, p2)	\
 	MakeParamVector( IUTEST_PP_CAT(p1, i), IUTEST_PP_CAT(p2, i) );
-#define IUTEST_DECL_PAIRWISE_GENERATOR_PARAM_SIZE_(i, param)		\
+#define IIUT_DECL_PAIRWISE_GENERATOR_PARAM_SIZE_(i, param)			\
 	static_cast<int>( IUTEST_PP_CAT(param, i).size() )
-#define IUTEST_DECL_PAIRWISE_GENERATOR_GETPARAM_(i, param)			\
+#define IIUT_DECL_PAIRWISE_GENERATOR_GETPARAM_(i, param)			\
 	GetParam( IUTEST_PP_CAT(param, i), indexes, i)
 
-#define IUTEST_DECL_PAIRWISE_GENERATOR_(n)				\
+#define IIUT_DECL_PAIRWISE_GENERATOR_(n)				\
 	template< IUTEST_PP_ENUM_PARAMS(n, typename T) >	\
 	class IUTEST_PP_CAT(iuPairwiseGenerator, n) : public iuPairwiseGeneratorBase {	\
-		IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_, typedef iuParamGenerator, Generator)	\
+		IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_, typedef iuParamGenerator, Generator)	\
 		typedef ParamIndexes<n> _MyParamIndexes;							\
 		typedef ::std::vector< _MyParamIndexes > ParamIndexesList;			\
 	public: typedef tuples::tuple< IUTEST_PP_ENUM_PARAMS(n, T) > ParamType;	\
 		static iuIParamGenerator< ParamType >* Create(						\
 			IUTEST_PP_ENUM_BINARY_PARAMS(n, Generator, g) ) {				\
 			ParamIndexesList list;											\
-			IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_, ::std::vector, params)	\
-			IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_PAIRWISE_GENERATOR_MAKEPARAM_VECTOR_, params, g)			\
-			int count_list[] = { IUTEST_PP_ENUM(n, IUTEST_DECL_PAIRWISE_GENERATOR_PARAM_SIZE_, params) };	\
+			IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_, ::std::vector, params)	\
+			IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_PAIRWISE_GENERATOR_MAKEPARAM_VECTOR_, params, g)		\
+			int count_list[] = { IUTEST_PP_ENUM(n, IIUT_DECL_PAIRWISE_GENERATOR_PARAM_SIZE_, params) };	\
 			MakeIndexList(list, count_list);								\
 			::std::vector<ParamType> params;								\
 			for( typename ParamIndexesList::const_iterator it=list.begin(), end=list.end(); it != end; ++it ) {		\
 				const _MyParamIndexes& indexes = *it;						\
-				params.push_back( ParamType( IUTEST_PP_ENUM(n, IUTEST_DECL_PAIRWISE_GENERATOR_GETPARAM_, params) ) );	\
+				params.push_back( ParamType( IUTEST_PP_ENUM(n, IIUT_DECL_PAIRWISE_GENERATOR_GETPARAM_, params) ) );	\
 			}																\
-			return new iuValueInParamsGenerator< ParamType >(params);		\
+			return new iuValuesInParamsGenerator< ParamType >(params);		\
 		}																	\
 	}
 
-IUTEST_DECL_PAIRWISE_GENERATOR_(3);
-IUTEST_DECL_PAIRWISE_GENERATOR_(4);
-IUTEST_DECL_PAIRWISE_GENERATOR_(5);
-IUTEST_DECL_PAIRWISE_GENERATOR_(6);
-IUTEST_DECL_PAIRWISE_GENERATOR_(7);
-IUTEST_DECL_PAIRWISE_GENERATOR_(8);
-IUTEST_DECL_PAIRWISE_GENERATOR_(9);
+IIUT_DECL_PAIRWISE_GENERATOR_(3);
+IIUT_DECL_PAIRWISE_GENERATOR_(4);
+IIUT_DECL_PAIRWISE_GENERATOR_(5);
+IIUT_DECL_PAIRWISE_GENERATOR_(6);
+IIUT_DECL_PAIRWISE_GENERATOR_(7);
+IIUT_DECL_PAIRWISE_GENERATOR_(8);
+IIUT_DECL_PAIRWISE_GENERATOR_(9);
 
-#undef IUTEST_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_
-#undef IUTEST_DECL_PAIRWISE_GENERATOR_MAKEPARAM_VECTOR_
-#undef IUTEST_DECL_PAIRWISE_GENERATOR_PARAM_SIZE_
-#undef IUTEST_DECL_PAIRWISE_GENERATOR_GETPARAM_
-#undef IUTEST_DECL_PAIRWISE_GENERATOR_
+#undef IIUT_DECL_PAIRWISE_GENERATOR_TEMPLATE_T_
+#undef IIUT_DECL_PAIRWISE_GENERATOR_MAKEPARAM_VECTOR_
+#undef IIUT_DECL_PAIRWISE_GENERATOR_PARAM_SIZE_
+#undef IIUT_DECL_PAIRWISE_GENERATOR_GETPARAM_
+#undef IIUT_DECL_PAIRWISE_GENERATOR_
 
 /*
 template<typename Generator1, typename Generator2>
@@ -1116,45 +1127,126 @@ private:
 };
 */
 
-#define IUTEST_DECL_PAIRWISE_HOLDER_CONSTRUCT_(i, p1, p2)	IUTEST_PP_CAT(p1, i)(IUTEST_PP_CAT(p2, i))
-#define IUTEST_DECL_PAIRWISE_HOLDER_STATICCAST_(i, p1, p2)	\
+#define IIUT_DECL_PAIRWISE_HOLDER_CONSTRUCT_(i, p1, p2)	IUTEST_PP_CAT(p1, i)(IUTEST_PP_CAT(p2, i))
+#define IIUT_DECL_PAIRWISE_HOLDER_STATICCAST_(i, p1, p2)	\
 	static_cast< iuIParamGenerator< IUTEST_PP_CAT(p1, i) >* >(IUTEST_PP_CAT(p2, i))
-#define IUTEST_DECL_PAIRWISE_HOLDER_VARIABLE_(i, p1, p2)	IUTEST_PP_CAT(p1, i) IUTEST_PP_CAT(p2, i);
+#define IIUT_DECL_PAIRWISE_HOLDER_VARIABLE_(i, p1, p2)	IUTEST_PP_CAT(p1, i) IUTEST_PP_CAT(p2, i);
 
-#define IUTEST_DECL_PAIRWISE_HOLDER_(n)	\
+#define IIUT_DECL_PAIRWISE_HOLDER_(n)	\
 	template< IUTEST_PP_ENUM_PARAMS(n, typename Generator) >	\
 	class IUTEST_PP_CAT(iuPairwiseHolder, n) {					\
 		typedef IUTEST_PP_CAT(iuPairwiseHolder, n)< IUTEST_PP_ENUM_PARAMS(n, Generator) > _Myt;		\
 	public: IUTEST_PP_CAT(iuPairwiseHolder, n)(					\
 		IUTEST_PP_ENUM_BINARY_PARAMS(n, const Generator, &g) )	\
-		: IUTEST_PP_ENUM_BINARY(n, IUTEST_DECL_PAIRWISE_HOLDER_CONSTRUCT_, m_g, g) {}				\
+		: IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_CONSTRUCT_, m_g, g) {}					\
 		template< IUTEST_PP_ENUM_PARAMS(n, typename T) >		\
 		operator iuIParamGenerator< tuples::tuple< IUTEST_PP_ENUM_PARAMS(n, T) > >* (void) const {	\
 			return IUTEST_PP_CAT(iuPairwiseGenerator, n)< IUTEST_PP_ENUM_PARAMS(n, T) >::Create(	\
-				IUTEST_PP_ENUM_BINARY(n, IUTEST_DECL_PAIRWISE_HOLDER_STATICCAST_, T, m_g) );		\
+				IUTEST_PP_ENUM_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_STATICCAST_, T, m_g) );			\
 		}														\
 	private: void operator = (const _Myt&) {}					\
-		IUTEST_PP_REPEAT_BINARY(n, IUTEST_DECL_PAIRWISE_HOLDER_VARIABLE_, const Generator, m_g)		\
+		IUTEST_PP_REPEAT_BINARY(n, IIUT_DECL_PAIRWISE_HOLDER_VARIABLE_, const Generator, m_g)		\
 	}
 
-IUTEST_DECL_PAIRWISE_HOLDER_(2);
-IUTEST_DECL_PAIRWISE_HOLDER_(3);
-IUTEST_DECL_PAIRWISE_HOLDER_(4);
-IUTEST_DECL_PAIRWISE_HOLDER_(5);
-IUTEST_DECL_PAIRWISE_HOLDER_(6);
-IUTEST_DECL_PAIRWISE_HOLDER_(7);
-IUTEST_DECL_PAIRWISE_HOLDER_(8);
-IUTEST_DECL_PAIRWISE_HOLDER_(9);
+IIUT_DECL_PAIRWISE_HOLDER_(2);
+IIUT_DECL_PAIRWISE_HOLDER_(3);
+IIUT_DECL_PAIRWISE_HOLDER_(4);
+IIUT_DECL_PAIRWISE_HOLDER_(5);
+IIUT_DECL_PAIRWISE_HOLDER_(6);
+IIUT_DECL_PAIRWISE_HOLDER_(7);
+IIUT_DECL_PAIRWISE_HOLDER_(8);
+IIUT_DECL_PAIRWISE_HOLDER_(9);
 
-#undef IUTEST_DECL_PAIRWISE_HOLDER_CONSTRUCT_
-#undef IUTEST_DECL_PAIRWISE_HOLDER_STATICCAST_
-#undef IUTEST_DECL_PAIRWISE_HOLDER_VARIABLE_
-#undef IUTEST_DECL_PAIRWISE_HOLDER_
+#undef IIUT_DECL_PAIRWISE_HOLDER_CONSTRUCT_
+#undef IIUT_DECL_PAIRWISE_HOLDER_STATICCAST_
+#undef IIUT_DECL_PAIRWISE_HOLDER_VARIABLE_
+#undef IIUT_DECL_PAIRWISE_HOLDER_
 
 #endif
 
 #endif
 
+#if IUTEST_HAS_VALUESGEN
+
+/**
+ * @breif	p[^
+ * @tparam G	= p[^
+*/
+template<typename G>
+class iuValuesParamsGeneratorHolder
+{
+public:
+	iuValuesParamsGeneratorHolder(size_t num, const G& g)
+		: m_num(num), m_g(g)
+	{}
+public:
+	template<typename T>
+	operator iuIParamGenerator<T>* () const 
+	{
+		::std::vector<T> params(m_num);
+		::std::generate(params.begin(), params.end(), m_g);
+		return new iuValuesInParamsGenerator<T>( params );
+	}
+private:
+	size_t m_num;
+	G m_g;
+};
+
+/**
+ * @brief	WFl[^
+*/
+template<typename T, typename F>
+class iuRandomFilterParamGenerator
+{
+	typedef T	type;
+public:
+	iuRandomFilterParamGenerator(const F& fn, unsigned int seed)
+		: m_fn(fn), m_rnd(seed) {}
+
+	type operator ()(void)
+	{
+		for(;;)
+		{
+			type val =  m_rnd.genrand();
+			if( (m_fn)(val) ) return val;
+		}
+	}
+private:
+	F m_fn;
+	iuTypedRandom<type> m_rnd;
+};
+
+#endif
+
+#if IUTEST_HAS_RANDOMVALUES
+
+/**
+ * @breif	p[^
+*/
+class iuRandomParamsHolder
+{
+public:
+	iuRandomParamsHolder(size_t num, unsigned int seed=0) IUTEST_CXX_NOEXCEPT_SPEC
+		: m_num(num), m_seed(seed) {}
+public:
+	template<typename T>
+	operator iuIParamGenerator<T>* () const 
+	{
+		unsigned int seed = m_seed;
+		if( seed == 0 )
+		{
+			seed = GetIndefiniteValue();
+		}
+		iuValuesParamsGeneratorHolder< iuTypedRandom<T> > gen( m_num, iuTypedRandom<T>(seed) );
+		return gen;
+	}
+private:
+	size_t m_num;
+	unsigned int m_seed;
+};
+
+#endif
+
 }	// end of namespace detail
 }	// end of namespace iutest
 
