@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -68,27 +68,37 @@ public:
 	const	char*	name(void)					const	{ return m_testcase_name.c_str(); }
 
 	/** eXg */
-	int				total_test_count(void)		const	{ return m_testinfos.size(); }
+	int				total_test_count(void)		const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_testinfos.size(); }
+	/** |[gΏۂ̃eXg */
+	int				reportable_test_count(void)	const;
 	/** seXg */
-	int				test_to_run_count(void)		const	{ return m_should_run_num; }
+	int				test_to_run_count(void)		const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_should_run_num; }
 	/** seXg */
-	int				failed_test_count(void)		const	{ return get_failed_test_count(); }
+	int				failed_test_count(void)		const;
 	/** eXg */
-	int				disabled_test_count(void)	const	{ return m_disable_num; }
+	int				disabled_test_count(void)	const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_disable_num; }
+	/** |[gΏۂ̖eXg */
+	int				reportable_disabled_test_count(void) const;
 	/** eXg */
-	int				successful_test_count(void)	const	{ return test_to_run_count() - failed_test_count(); }
+	int				successful_test_count(void)	const;
 	/** XLbveXg */
-	int				skip_test_count(void)		const	{ return get_skipped_test_count(); }
+	int				skip_test_count(void)		const;
+	/** |[gΏۂ̃XLbveXg */
+	int				reportable_skip_test_count(void) const;
+	/** IɃXLbvꂽeXg */
+	int				test_was_skipped_count(void) const;
+	/** |[gΏۂ̖IɃXLbvꂽeXg */
+	int				reportable_test_was_skipped_count(void) const;
 	/** eXg̎s~b */
-	TimeInMillisec	elapsed_time(void)			const	{ return m_elapsedmsec; }
+	TimeInMillisec	elapsed_time(void)			const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_elapsedmsec; }
 
 	/** TestInfo ̎擾 */
 	const TestInfo*	GetTestInfo(int index)		const	{ return m_testinfos[index]; }
 	/** should_run */
-	bool			should_run(void)			const	{ return m_should_run_num != 0; }
+	bool			should_run(void)			const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_should_run_num != 0; }
 
 	/** eXgǂ */
-	bool			Passed(void)				const	{ return get_failed_test_count() == 0; }
+	bool			Passed(void)				const	{ return failed_test_count() == 0 && m_ad_hoc_testresult.Passed(); }
 	/** eXgsǂ */
 	bool			Failed(void)				const	{ return !Passed(); }
 
@@ -107,6 +117,9 @@ public:
 		return str;
 	}
 
+	/** eXgsȂƂ̃Ug̎擾 */
+	const TestResult* ad_hoc_testresult(void) const IUTEST_CXX_NOEXCEPT_SPEC { return &m_ad_hoc_testresult; }
+
 private:
 	/**
 	 * @brief	eXg̎s
@@ -150,11 +163,6 @@ private:
 	*/
 	bool	filter(void);
 
-	/** seXg */
-	int get_failed_test_count(void) const;
-	/** XLbveXg */
-	int get_skipped_test_count(void) const;
-
 private:
 	friend bool	operator == (const TestCase& lhs, const TestCase& rhs)
 	{
@@ -166,12 +174,25 @@ private:
 private:
 	iuTestInfos::const_iterator	begin(void)	const		{ return m_testinfos.begin(); }
 	iuTestInfos::const_iterator	end(void)	const		{ return m_testinfos.end(); }
-	TestTypeId					get_typeid(void) const	{ return m_id; }
+	TestTypeId					get_typeid(void) const IUTEST_CXX_NOEXCEPT_SPEC	{ return m_id; }
+
+private:
+	static bool IsSuccessfulTest(const TestInfo* p) { return p->is_ran() && !p->HasFailure(); }
+	static bool IsFaildTest(const TestInfo* p) { return p->should_run() && p->HasFailure(); }
+	static bool IsSkipTest(const TestInfo* p) { return !p->is_ran() || p->is_skipped(); }
+	static bool IsReportableSkipTest(const TestInfo* p) { return p->is_reportable() && IsSkipTest(p); }
+	static bool IsWasSkippedTest(const TestInfo* p) { return p->should_run() && p->is_skipped(); }
+	static bool IsReportableWasSkippedTest(const TestInfo* p) { return p->is_reportable() && IsWasSkippedTest(p); }
+	static bool IsReportableDisabledTest(const TestInfo* p) { return p->is_reportable() && p->is_disabled_test(); }
 
 private:
 	friend class UnitTestImpl;
 	friend class UnitTest;
 
+#if defined(IUTEST_NO_PRIVATE_IN_AGGREGATE)
+	friend struct FindOp;
+#endif
+
 	::std::string	m_testcase_name;	//!< eXgP[X
 	iuTestInfos		m_testinfos;		//!< eXg񃊃Xg
 	SetUpMethod		m_setup;			//!< SetUp ֐
@@ -181,6 +202,7 @@ private:
 	int				m_should_run_num;	//!< sׂeXg̑
 	TimeInMillisec	m_elapsedmsec;		//!< eXg
 	bool			m_disable;			//!< ^Ul
+	TestResult		m_ad_hoc_testresult;	//!< eXgsłȂƂ̃Ug
 
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(TestCase);
 };
@@ -209,7 +231,7 @@ protected:
 
 public:
 	/** type param ̎擾 */
-	virtual const char*	type_param(void) const	{ return m_type_param.empty() ? NULL : m_type_param.c_str(); }
+	virtual const char*	type_param(void) const IUTEST_CXX_OVERRIDE	{ return m_type_param.empty() ? NULL : m_type_param.c_str(); }
 
 private:
 	friend class UnitTestImpl;
@@ -226,109 +248,17 @@ namespace detail
 class TestCaseMediator : public detail::iuITestCaseMediator
 {
 public:
-	TestCaseMediator(TestCase* p) : iuITestCaseMediator(p) {}
+	TestCaseMediator(TestCase* p) IUTEST_CXX_NOEXCEPT_SPEC : iuITestCaseMediator(p) {}
 public:
-	virtual const char*	test_case_name(void) const { return m_test_case->name(); }
-	virtual const char*	type_param(void) const	{ return m_test_case->type_param(); }
+	virtual const char*	test_case_name(void) const IUTEST_CXX_OVERRIDE IUTEST_CXX_FINAL { return m_test_case->name(); }
+	virtual const char*	type_param(void)	 const IUTEST_CXX_OVERRIDE IUTEST_CXX_FINAL { return m_test_case->type_param(); }
 };
 
 }	// end of namespace detail
-
-inline bool	TestCase::Run(void)
-{
-	if( !should_run() ) return true;
-
-	if( TestFlag::IsEnableFlag(TestFlag::SHUFFLE_TESTS) )
-	{
-		RandomShuffle(m_testinfos, TestEnv::genrand());
-	}
-
-	// eXgJn
-	TestEnv::event_listeners().OnTestCaseStart(*this);
-	bool result = RunImpl();
-	// eXgI
-	TestEnv::event_listeners().OnTestCaseEnd(*this);
-
-	return result;
-}
-
-inline bool TestCase::RunImpl(void)
-{
-	bool result=true;
-	m_elapsedmsec = 0;
-
-	m_setup();
-	{
-		detail::iuStopWatch sw;
-		sw.start();
-		for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-		{
-			if( (*it)->should_run() )
-			{
-				// s
-				if( !(*it)->Run() )
-				{
-					result = false;
-				}
-			}
-		}
-		m_elapsedmsec = sw.stop();
-	}
-	m_teardown();
-	return result;
-}
-
-inline void	TestCase::clear(void)
-{
-	for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-	{
-		(*it)->clear();
-	}
-}
-
-inline bool	TestCase::filter(void)
-{
-	m_should_run_num = 0;
-	m_disable_num = 0;
-	for( iuTestInfos::iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-	{
-		if( m_disable )
-		{
-			// DISABLE ̓`
-			(*it)->m_disable = true;
-		}
-		if( (*it)->is_disabled_test() )
-		{
-			++m_disable_num;
-		}
-		if( (*it)->filter() )
-		{
-			++m_should_run_num;
-		}
-	}
-	return should_run();
-}
-
-inline int TestCase::get_failed_test_count(void) const
-{
-	int count = 0;
-	for( iuTestInfos::const_iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-	{
-		if( (*it)->should_run() && (*it)->HasFailure() ) ++count;
-	}
-	return count;
-}
-
-inline int TestCase::get_skipped_test_count(void) const
-{
-	int count = 0;
-	for( iuTestInfos::const_iterator it = m_testinfos.begin(), end=m_testinfos.end(); it != end; ++it )
-	{
-		if( (*it)->is_skipped() ) ++count;
-	}
-	return count;
-}
-
 }	// end of namespace iutest
 
+#if !IUTEST_HAS_LIB
+#  include "impl/iutest_case.ipp"
+#endif
+
 #endif
