@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -22,11 +22,11 @@
 
 //======================================================================
 // define
-#define	IUTEST_VER			0x01020002u	//!< iutest version 1.2.0.2
+#define	IUTEST_VER			0x01060000u	//!< iutest version 1.6.0.0
 #define IUTEST_MAJORVER		0x01u		//!< Major Version
-#define IUTEST_MINORVER		0x02u		//!< Minor Version
+#define IUTEST_MINORVER		0x06u		//!< Minor Version
 #define IUTEST_BUILD		0x00u		//!< Build
-#define IUTEST_REVISION		0x02u		//!< Revision
+#define IUTEST_REVISION		0x00u		//!< Revision
 
 /**
  * @mainpage
@@ -35,7 +35,7 @@
  *			github      : https://github.com/srz-zumix/iutest \n
  *
  * @par		copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  *
  * @par		LICENSE
@@ -72,6 +72,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    <tr><td>--help, -h                        </td><td></td><td>generate help message.</td></tr>
    <tr><td>--iutest_output                   </td><td>xml[:path]</td><td>path of xml report.</td></tr>
    <tr><td>--iutest_list_tests               </td><td></td><td>list up tests.</td></tr>
+   <tr><td>--iutest_list_tests_with_where    </td><td></td><td>list up tests with where.</td></tr>
    <tr><td>--iutest_color                    </td><td>&lt;yes|no|auto|ansi&gt;</td><td>console color enable.</td></tr>
    <tr><td>--iutest_filter                   </td><td>&lt;filter&gt;</td><td>Select the test run.</td></tr>
    <tr><td>--iutest_shuffle                  </td><td></td><td>do shuffle test.</td></tr>
@@ -82,6 +83,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
    <tr><td>--iutest_catch_exceptions         </td><td>&lt;0|1&gt;</td><td>catch exceptions enable.</td></tr>
    <tr><td>--iutest_print_time               </td><td>&lt;0|1&gt;</td><td>Setting the display of elapsed time.</td></tr>
    <tr><td>--iutest_repeat                   </td><td>&lt;count&gt;</td><td>Set the number of repetitions of the test.</td></tr>
+   <tr><td>--iutest_stream_result_to         </td><td>&lt;host:port&gt;</td><td>Set stream test results server.</td></tr>
+   <tr><td>--iutest_file_location            </td><td>&lt;auto|vs|gcc&gt;</td><td>Format file location messages.</td></tr>
    <tr><td>--feature                         </td><td></td><td>show iutest feature.</td></tr>
    <tr><td>--version, -v                     </td><td></td><td>show iutest version.</td></tr>
  </table>
@@ -92,6 +95,75 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  * @page	CHANGELOG		ύX
  * @par		Changes
  <ul>
+  <li>v1.6.0.0
+    <ul>
+      <li>stream result Ή</li>
+      <li>gtest [h AssertionReturn g悤ɑΉ</li>
+      <li>AssertionReturn ̎dlύX</li>
+      <li>::iutest::RandomGenerator ǉ</li>
+      <li>::iutest::RandomValues ŗV[hwł悤ɏC</li>
+      <li>spi  TestPartResult `FbN悤ɕύX</li>
+      <li>spi  substr ŃbZ[W`FbN悤ɕύX</li>
+	  <li>ASSERT_*, EXPECT_*, INFORM_* }ÑXg[ iomanip gpłȂC</li>
+    </ul>
+  </li>
+  <li>v1.5.0.4
+    <ul>
+      <li>--iutest_filter Ń}b`ȂeXg XML ɏo͂Ȃ悤ɕύX</li>
+      <li>XML o͂ skipped ɃbZ[Wo͂悤ɏC</li>
+      <li>--iutest_filter Ƀ}b`eXg擾ł悤ɏC</li>
+      <li>ftHgOo͂ --iutest_filter ̌ʂlo͂ɕύX</li>
+    </ul>
+  </li>
+  <li>v1.5.0.0
+    <ul>
+      <li>{eXgɑΉ</li>
+      <li>SetUpTestCase Ȃǂ̃eXgsȊOł RecordProperty ł悤ɕύX</li>
+      <li>iutest_list_tests_with_where R}hCIvVǉ</li>
+      <li>IUTEST_TYPED_TEST_CASE,IUTEST_TYPED_TEST_CASE_P ɒ ::iutest::Types 悤ɏC/li>
+      <li>gꍇɃG[o͂悤ɏC</li>
+      <li>IUTEST_PEEP ̎dlύX</li>
+      <li>MiniDump o͂ɑΉ</li>
+      <li>noexcept ɑΉ</li>
+    </ul>
+  </li>
+  <li>v1.4.0.0
+    <ul>
+      <li>IUTEST_ASSERT_*  void ȊO̖߂lԂ悤ɏC(::iutest::AssertionReturn)</li>
+      <li>::iutest::Types o[Ɍ^擾 get ǉ</li>
+      <li>::iutest::ValuesIn  initializer_list ɑΉ</li>
+      <li>l̃p[^eXgɔCӂ̃p[^𐶐 ValuesGen ǉ</li>
+      <li>l̃p[^eXgɗp[^𐶐 RandomValues ǉ</li>
+      <li>extern template Ή</li>
+      <li>C++11 random wb_[gpłƂ distribution g悤ɕύX</li>
+      <li>R[h̓c[̂߂̃R[h̒ǉ(__analysis_assume)  IUTEST_*_NULL  IUTEST_*_NOTNULL ɒǉ(MSVC)</li>
+	  <li>ÂRpCւ̑Ή</li>
+    </ul>
+  </li>
+  <li>v1.3.1.0
+    <ul>
+      <li>IUTEST_SKIP Ƃ̃Oǉ</li>
+      <li>IUTEST_SKIP() << "message" ɑΉ</li>
+      <li>XLbveXg̃Oo͂C</li>
+      <li>RpC̒ʂȂeXgR[heXg}N(*_IGNORE)ǉ</li>
+    </ul>
+  </li>
+  <li>v1.3.0.1
+    <ul>
+      <li>IUTEST_THROW_ON_ASSERT_FAILURE  IUTEST_USE_THROW_ON_ASSERT_FAILURE ɕύX</li>
+      <li>IUTEST_FRIEND_TYPED_TEST ǉ</li>
+      <li>V[hJԂɕKς悤ɏC</li>
+      <li>GTEST Ŏn܂ϐɑΉ</li>
+      <li>bZ[Wo͂̃t@C/s̃tH[}bg𓮓IɕύXłIvVǉ(--iutest_file_location)</li>
+      <li>gtest [hł̃rhG[C</li>
+      <li>IUTEST_*_FATAL_FAILURE, IUTEST_*_NONFATAL_FAILURE  lambda 𗘗pĕϐɃANZXł悤ɏC</li>
+      <li>IUTEST_*_NO_FATAL_FAILURE  FATAL FAILURE ݂̂Ŕf悤ɕύX</li>
+      <li>IUTEST_*_NO_FAILURE ǉ</li>
+      <li>CurhΉ</li>
+      <li>CUDA Ή</li>
+      <li>explicit conversion operator Ή</li>
+    </ul>
+  </li>
   <li>v1.2.0.2
     <ul>
       <li>IUTEST_*_EQ_COLLECTIONS AT[Vǉ</li>
