@@ -1,3 +1,19 @@
+//======================================================================
+//-----------------------------------------------------------------------
+/**
+ * @file		sub.cpp
+ * @brief		sample sub t@C
+ *
+ * @author		t.sirayanagi
+ * @version		1.0
+ *
+ * @par			copyright
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
+ * The new BSD License is applied to this software.
+ * see LICENSE
+*/
+//-----------------------------------------------------------------------
+//======================================================================
 
 /*
  * is not available vprintf, can be replaced.
@@ -11,18 +27,6 @@
 
 #if 1	// Success Tests
 
-/** --------------------------------------------------
- * PrintTo
-*//*--------------------------------------------------*/
-struct Bar
-{
-	int x, y, z;
-	bool operator == (const Bar& rhs) const
-	{
-		return x == rhs.x && y == rhs.y && z == rhs.z;
-	}
-};
-
 /** --------------------------------------------------
  * pbP[W
 *//*--------------------------------------------------*/
@@ -34,6 +38,20 @@ IUTEST_PACKAGE(TestPackage)
 	}
 }
 
+/** --------------------------------------------------
+ * PrintTo
+*//*--------------------------------------------------*/
+#if IUTEST_HAS_PRINT_TO
+
+struct Bar
+{
+	int x, y, z;
+	bool operator == (const Bar& rhs) const
+	{
+		return x == rhs.x && y == rhs.y && z == rhs.z;
+	}
+};
+
 ::iutest::iu_ostream& operator << (::iutest::iu_ostream& os, const Bar& bar) 
 {
 	return os << "X:" << bar.x << " Y:" << bar.y << " Z:" << bar.z;
@@ -51,8 +69,8 @@ IUTEST(PrintToTest, Test1)
 		a.push_back(i);
 	IUTEST_SUCCEED() << ::iutest::PrintToString(a);
 
-	int* pi;
-	void* p;
+	int* pi=NULL;
+	void* p=NULL;
 	IUTEST_SUCCEED() << ::iutest::PrintToString(p);
 	IUTEST_SUCCEED() << ::iutest::PrintToString(pi);
 
@@ -97,7 +115,7 @@ IUTEST(PrintToTest, RawArray)
 
 template<typename T>
 class TypedPrintToTest : public ::iutest::Test {};
-typedef ::iutest::Types<char, unsigned char, short, unsigned short, int, unsigned int, long, unsigned long> PrintStringTestTypes;
+typedef ::iutest::Types<char, unsigned char, short, unsigned short, int, unsigned int, long, unsigned long, int*> PrintStringTestTypes;
 IUTEST_TYPED_TEST_CASE(TypedPrintToTest, PrintStringTestTypes);
 
 IUTEST_TYPED_TEST(TypedPrintToTest, Print)
@@ -115,6 +133,7 @@ IUTEST_TYPED_TEST(TypedPrintToTest, Print)
 
 #endif
 
+#endif
 
 // DISABLED Test Tips.
 #define DISABLED_MacroTest	EnabledTest
