@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -29,8 +29,22 @@ int main(int argc, char* argv[])
 
 	IUTEST_EXPECT_EQ(0, 1);
 
-	int ret = IUTEST_RUN_ALL_TESTS();	// run all
-	if( ret != 0 ) printf("*** Successful ***\n");
-	return ret != 0 ? 0 : 1;
+	{
+		int ret = IUTEST_RUN_ALL_TESTS();
+		if( ret == 0 ) return 1;
+	}
+	{
+		int ret = IUTEST_RUN_ALL_TESTS();
+		if( ret == 0 ) return 1;
+	}
+#if !defined(IUTEST_USE_GTEST)
+	{
+		IUTEST_INIT(&argc, argv);
+		int ret = IUTEST_RUN_ALL_TESTS();
+		if( ret != 0 ) return 1;
+	}
+#endif
+	printf("*** Successful ***\n");
+	return 0;
 }
 
